macro_rules! error {
($($arg:tt)*) => { ... };
}Expand description
Logs a message at the error level, but only if the debug feature is enabled.
Delegates to log::error! internally.
macro_rules! error {
($($arg:tt)*) => { ... };
}Logs a message at the error level, but only if the debug feature is enabled.
Delegates to log::error! internally.